@@ -1,7 +1,7 @@
 /*
  * This file is part of bino, a 3D video player.
  *
- * Copyright (C) 2010-2011
+ * Copyright (C) 2010, 2011, 2015
  * Martin Lambers <marlam@marlam.de>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -47,10 +47,10 @@ extern "C"
 #  include <eq/eq.h>
 #endif
 
-#include "gettext.h"
-#define _(string) gettext(string)
+#include "base/str.h"
 
-#include "str.h"
+#include "base/gettext.h"
+#define _(string) gettext(string)
 
 
 static std::vector<std::string> ffmpeg_v;
